uniform sampler2D colorMap;

// center of lens for un-distortion (in normalized coordinates between 0 and 1)
uniform vec2 centerCoordinate;

// lens distortion parameters
uniform vec2 K; 

varying vec2 vUv;

void main() {

	// distance from center
	float rad	= distance(vUv,centerCoordinate);
	rad *= rad;

	// compute undistorted texture coordinates 
	vec2 texCoordsUndistorted = (vUv.xy - centerCoordinate) * (1.0 + K[0] * rad + K[1] * rad * rad);
	
	texCoordsUndistorted = texCoordsUndistorted + centerCoordinate;

	if(texCoordsUndistorted.x < 0.0 || texCoordsUndistorted.y < 0.0 || 
		 texCoordsUndistorted.x > 1.0 || texCoordsUndistorted.y > 1.0) {
		gl_FragColor = vec4(0, 0, 0, 1);
	} else {
		// Index into texture with undistored coordinates
		gl_FragColor = texture2D(colorMap, texCoordsUndistorted);
	}
}
